/*
Copyright (c) 2020-present NAVER Corp.
name: @egjs/vue3-view3d
license: MIT
author: NAVER Corp.
repository: https://github.com/naver/egjs-view3d/tree/master/packages/vue3-view3d
version: 2.1.0
*/
'use strict';

var vue = require('vue');
var VanillaView3D = require('@egjs/view3d');

/******************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */
var __assign = function () {
  __assign = Object.assign || function __assign(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
      s = arguments[i];

      for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
    }

    return t;
  };

  return __assign.apply(this, arguments);
};

var view3DOptionNames = Object.getOwnPropertyNames(VanillaView3D.prototype).filter(function (name) {
  var descriptor = Object.getOwnPropertyDescriptor(VanillaView3D.prototype, name);
  if (name.startsWith("_")) return false;
  if (descriptor === null || descriptor === void 0 ? void 0 : descriptor.value) return false;
  return true;
});
var view3DOptions = view3DOptionNames.reduce(function (props, name) {
  var _a;

  return __assign(__assign({}, props), (_a = {}, _a[name] = null, _a));
}, {});
var view3DSetterNames = view3DOptionNames.filter(function (name) {
  var descriptor = Object.getOwnPropertyDescriptor(VanillaView3D.prototype, name);
  return !!descriptor.set;
});
var View3D = vue.defineComponent({
  props: __assign(__assign({}, view3DOptions), {
    tag: {
      type: String,
      required: false,
      default: "div"
    },
    canvasClass: {
      type: String,
      required: false,
      default: ""
    }
  }),
  data: function () {
    return {};
  },
  created: function () {
    VanillaView3D.withMethods(this, "view3D");
  },
  mounted: function () {
    var _this = this;

    var props = VanillaView3D.getValidProps(this.$props);
    this.view3D = new VanillaView3D(this.$refs.wrapper, props);
    var events = Object.keys(VanillaView3D.EVENTS).map(function (key) {
      return VanillaView3D.EVENTS[key];
    });
    events.forEach(function (eventName) {
      _this.view3D.on(eventName, function (e) {
        e.target = _this; // Make events from camelCase to kebab-case

        _this.$emit(eventName.replace(/([A-Z])/g, "-$1").toLowerCase(), e);
      });
    });
  },
  beforeUnmount: function () {
    var _a;

    (_a = this.view3D) === null || _a === void 0 ? void 0 : _a.destroy();
  },
  render: function () {
    var _a, _b, _c;

    var canvasClass = (_a = this.canvasClass) !== null && _a !== void 0 ? _a : "";
    var canvasClassName = "".concat(VanillaView3D.DEFAULT_CLASS.CANVAS, " ").concat(canvasClass).trim();
    return vue.h(this.tag, {
      ref: "wrapper",
      class: VanillaView3D.DEFAULT_CLASS.WRAPPER
    }, [vue.h("canvas", {
      class: canvasClassName
    }), (_c = (_b = this.$slots).default) === null || _c === void 0 ? void 0 : _c.call(_b)]);
  },
  watch: __assign({}, view3DSetterNames.reduce(function (setters, name) {
    setters["$props.".concat(name)] = {
      handler: function (newVal) {
        if (!this.view3D) return;
        this.view3D[name] = newVal;
      },
      deep: true
    };
    return setters;
  }, {}))
});

var index_umd = {
  install: function (app) {
    app.component("View3D", View3D);
  },
  View3D: View3D
};

module.exports = index_umd;
//# sourceMappingURL=view3d.cjs.js.map
